"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Module for installing Convert native modules and executables
 *
 * The [`pkg`](https://github.com/zeit/pkg) Node.js packager does not
 * package native modules.  i.e `*.node` files. There are various ways to handle this but
 * we found the easiest/safest was to simply copy the directories for the
 * packages with native modules, from the host system, into directory where the
 * binary is installed. This script does that via `convert-deps.tar.gz` which is
 * packaged in the binary snapshot as an `asset`.
 *
 * See:
 *   - https://github.com/stencila/convert/pull/47#issuecomment-489912132
 *   - https://github.com/zeit/pkg/issues/329
 *   - https://github.com/JoshuaWise/better-sqlite3/issues/173
 *   - `package.json`
 */
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const puppeteer_1 = __importDefault(require("puppeteer"));
const tar_1 = __importDefault(require("tar"));
// @ts-ignore
const pandoc_binary_1 = __importDefault(require("./pandoc-binary"));
/**
 * Is this process being run as a `pkg` packaged binary?
 */
exports.packaged = ((process.mainModule && process.mainModule.id.endsWith('.exe')) ||
    process.hasOwnProperty('pkg')) &&
    fs_extra_1.default.existsSync(path_1.default.join('/', 'snapshot'));
/**
 * The home directory for this modules or process where
 * native modules and executables are placed.
 */
exports.home = exports.packaged
    ? path_1.default.dirname(process.execPath)
    : path_1.default.dirname(__dirname);
// Unzip the native dependencies to home
if (exports.packaged && !fs_extra_1.default.existsSync(path_1.default.join(exports.home, 'node_modules'))) {
    tar_1.default.x({
        sync: true,
        file: path_1.default.join('/', 'snapshot', 'convert', 'convert-deps.tgz'),
        C: exports.home
    });
}
/**
 * The following code is necessary to ensure the Chromium binary can be correctly
 * found when bundled as a binary using [`pkg`](https://github.com/zeit/pkg).
 * See: [`pkg-puppeteer`](https://github.com/rocklau/pkg-puppeteer)
 */
// Adapts the regex path to work on both Windows and *Nix platforms
const pathRegex = process.platform === 'win32'
    ? /^.*?\\node_modules\\puppeteer\\\.local-chromium/
    : /^.*?\/node_modules\/puppeteer\/\.local-chromium/;
exports.chromiumPath = exports.packaged
    ? puppeteer_1.default
        .executablePath()
        .replace(pathRegex, path_1.default.join(path_1.default.dirname(process.execPath), 'node_modules', 'puppeteer', '.local-chromium'))
    : puppeteer_1.default.executablePath();
/**
 * The path to the Pandoc binary executable
 */
exports.pandocPath = path_1.default.join(exports.home, pandoc_binary_1.default.path());
/**
 * Equivalent to the Pandoc `--data-dir` flag.
 * Instructs Pandoc where to templates and other assets.
 */
exports.pandocDataDir = path_1.default.join(exports.home, 'src');
