"use strict";
/**
 * JATS compiler
 *
 * Compiler for [Journal Article Tag Suite (JATS)](https://en.wikipedia.org/wiki/Journal_Article_Tag_Suite).
 */
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const pandoc = __importStar(require("./pandoc"));
/**
 * Media types for this codec.
 *
 * There is currently no registered
 * [media type](https://www.iana.org/assignments/media-types/media-types.xhtml)
 * for JATS.
 *
 * This custom type uses the [convention](https://en.wikipedia.org/wiki/XML_and_MIME)
 * of using `application/` and the `+xml` suffix to differentiate this format from other
 * XML-based formats.
 */
exports.mediaTypes = ['application/jats+xml'];
/**
 * Extension names for this codec.
 */
exports.extNames = ['jats'];
// TODO: add a `sniff` function that check is a XML files
// and uses regex (for speed) for look for  JATs declaration
async function parse(file) {
    return pandoc.parse(file, pandoc.InputFormat.jats);
}
exports.parse = parse;
async function unparse(node, filePath) {
    return pandoc.unparse(node, filePath, pandoc.OutputFormat.jats, [
        `--standalone`,
        `--template=jats-template.xml`
    ]);
}
exports.unparse = unparse;
