"use strict";
/**
 * Typescript definitions for Pandoc.
 *
 * These type definitions are based on the definitions in
 * [`pandoc-types v1.17.5.4`](https://github.com/jgm/pandoc-types/blob/1.17.5.4/Text/Pandoc/Definition.hs).
 * That is the version used in Pandoc v2.7.2.
 *
 * Most of the comment strings are copy-pasted directly from there.
 *
 * To check these type definitions are correct with respect to what Pandoc actually
 * consumes and produces it can be useful to test Markdown or HTML snippets at the console like
 * this (`jq` used for ease of viewing output):
 *
 * ```bash
 * echo 'A "quote"' | ./vendor/bin/pandoc --from markdown --to json | jq .blocks
 * ```
 * ```json
 * [
 *   {
 *     "t": "Para",
 *     "c": [
 *       {
 *         "t": "Str",
 *         "c": "A"
 *       },
 *       {
 *         "t": "Space"
 *       },
 *       {
 *         "t": "Quoted",
 *         "c": [
 * ...
 * ```
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Version = [1, 17, 5, 4];
/**
 * Style of list numbers.
 */
var ListNumberStyle;
(function (ListNumberStyle) {
    ListNumberStyle["DefaultStyle"] = "DefaultStyle";
    ListNumberStyle["Example"] = "Example";
    ListNumberStyle["Decimal"] = "Decimal";
    ListNumberStyle["LowerRoman"] = "LowerRoman";
    ListNumberStyle["UpperRoman"] = "UpperRoman";
    ListNumberStyle["LowerAlpha"] = "LowerAlpha";
    ListNumberStyle["UpperAlpha"] = "UpperAlpha";
})(ListNumberStyle = exports.ListNumberStyle || (exports.ListNumberStyle = {}));
/**
 * Delimiter of list numbers.
 */
var ListNumberDelim;
(function (ListNumberDelim) {
    ListNumberDelim["DefaultDelim"] = "DefaultDelim";
    ListNumberDelim["Period"] = "Period";
    ListNumberDelim["OneParen"] = "OneParen";
    ListNumberDelim["TwoParen"] = "TwoParen";
})(ListNumberDelim = exports.ListNumberDelim || (exports.ListNumberDelim = {}));
/**
 * Alignment of a table column.
 */
var Alignment;
(function (Alignment) {
    Alignment[Alignment["AlignLeft"] = 0] = "AlignLeft";
    Alignment[Alignment["AlignRight"] = 1] = "AlignRight";
    Alignment[Alignment["AlignCenter"] = 2] = "AlignCenter";
    Alignment[Alignment["AlignDefault"] = 3] = "AlignDefault";
})(Alignment = exports.Alignment || (exports.Alignment = {}));
/**
 * Type of quotation marks to use in Quoted inline.
 */
var QuoteType;
(function (QuoteType) {
    QuoteType["SingleQuote"] = "SingleQuote";
    QuoteType["DoubleQuote"] = "DoubleQuote";
})(QuoteType = exports.QuoteType || (exports.QuoteType = {}));
var CitationMode;
(function (CitationMode) {
    CitationMode[CitationMode["AuthorInText"] = 0] = "AuthorInText";
    CitationMode[CitationMode["SuppressAuthor"] = 1] = "SuppressAuthor";
    CitationMode[CitationMode["NormalCitation"] = 2] = "NormalCitation";
})(CitationMode = exports.CitationMode || (exports.CitationMode = {}));
/**
 * Type of math element (display or inline)
 */
var MathType;
(function (MathType) {
    MathType[MathType["DisplayMath"] = 0] = "DisplayMath";
    MathType[MathType["InlineMath"] = 1] = "InlineMath";
})(MathType = exports.MathType || (exports.MathType = {}));
/**
 * List of valid input formats. Generated using:
 *     ./vendor/bin/pandoc --list-input-formats
 */
var InputFormat;
(function (InputFormat) {
    InputFormat["commonmark"] = "commonmark";
    InputFormat["creole"] = "creole";
    InputFormat["docbook"] = "docbook";
    InputFormat["docx"] = "docx";
    InputFormat["dokuwiki"] = "dokuwiki";
    InputFormat["epub"] = "epub";
    InputFormat["fb2"] = "fb2";
    InputFormat["gfm"] = "gfm";
    InputFormat["haddock"] = "haddock";
    InputFormat["html"] = "html";
    InputFormat["ipynb"] = "ipynb";
    InputFormat["jats"] = "jats";
    InputFormat["json"] = "json";
    InputFormat["latex"] = "latex";
    InputFormat["man"] = "man";
    InputFormat["markdown"] = "markdown";
    InputFormat["markdown_github"] = "markdown_github";
    InputFormat["markdown_mmd"] = "markdown_mmd";
    InputFormat["markdown_phpextra"] = "markdown_phpextra";
    InputFormat["markdown_strict"] = "markdown_strict";
    InputFormat["mediawiki"] = "mediawiki";
    InputFormat["muse"] = "muse";
    InputFormat["native"] = "native";
    InputFormat["odt"] = "odt";
    InputFormat["opml"] = "opml";
    InputFormat["org"] = "org";
    InputFormat["rst"] = "rst";
    InputFormat["t2t"] = "t2t";
    InputFormat["textile"] = "textile";
    InputFormat["tikiwiki"] = "tikiwiki";
    InputFormat["twiki"] = "twiki";
    InputFormat["vimwiki"] = "vimwiki";
})(InputFormat = exports.InputFormat || (exports.InputFormat = {}));
/**
 * List of valid output formats. Generated using:
 *     ./vendor/bin/pandoc --list-output-formats
 */
var OutputFormat;
(function (OutputFormat) {
    OutputFormat["asciidoc"] = "asciidoc";
    OutputFormat["asciidoctor"] = "asciidoctor";
    OutputFormat["beamer"] = "beamer";
    OutputFormat["commonmark"] = "commonmark";
    OutputFormat["context"] = "context";
    OutputFormat["docbook"] = "docbook";
    OutputFormat["docbook4"] = "docbook4";
    OutputFormat["docbook5"] = "docbook5";
    OutputFormat["docx"] = "docx";
    OutputFormat["dokuwiki"] = "dokuwiki";
    OutputFormat["dzslides"] = "dzslides";
    OutputFormat["epub"] = "epub";
    OutputFormat["epub2"] = "epub2";
    OutputFormat["epub3"] = "epub3";
    OutputFormat["fb2"] = "fb2";
    OutputFormat["gfm"] = "gfm";
    OutputFormat["haddock"] = "haddock";
    OutputFormat["html"] = "html";
    OutputFormat["html4"] = "html4";
    OutputFormat["html5"] = "html5";
    OutputFormat["icml"] = "icml";
    OutputFormat["ipynb"] = "ipynb";
    OutputFormat["jats"] = "jats";
    OutputFormat["json"] = "json";
    OutputFormat["latex"] = "latex";
    OutputFormat["man"] = "man";
    OutputFormat["markdown"] = "markdown";
    OutputFormat["markdown_github"] = "markdown_github";
    OutputFormat["markdown_mmd"] = "markdown_mmd";
    OutputFormat["markdown_phpextra"] = "markdown_phpextra";
    OutputFormat["markdown_strict"] = "markdown_strict";
    OutputFormat["mediawiki"] = "mediawiki";
    OutputFormat["ms"] = "ms";
    OutputFormat["muse"] = "muse";
    OutputFormat["native"] = "native";
    OutputFormat["odt"] = "odt";
    OutputFormat["opendocument"] = "opendocument";
    OutputFormat["opml"] = "opml";
    OutputFormat["org"] = "org";
    OutputFormat["plain"] = "plain";
    OutputFormat["pptx"] = "pptx";
    OutputFormat["revealjs"] = "revealjs";
    OutputFormat["rst"] = "rst";
    OutputFormat["rtf"] = "rtf";
    OutputFormat["s5"] = "s5";
    OutputFormat["slideous"] = "slideous";
    OutputFormat["slidy"] = "slidy";
    OutputFormat["tei"] = "tei";
    OutputFormat["texinfo"] = "texinfo";
    OutputFormat["textile"] = "textile";
    OutputFormat["xwiki"] = "xwiki";
    OutputFormat["zimwiki"] = "zimwiki";
})(OutputFormat = exports.OutputFormat || (exports.OutputFormat = {}));
