import * as stencila from '@stencila/schema';
import * as Pandoc from './pandoc-types';
import { VFile } from './vfile';
export { InputFormat, OutputFormat } from './pandoc-types';
export declare const mediaTypes: string[];
export declare const extNames: string[];
/**
 * Parse a `VFile` to a `stencila.Node`.
 *
 * @param file The `VFile` to parse
 * @returns A promise that resolves to a `stencila.Node`
 */
export declare function parse(file: VFile, from?: Pandoc.InputFormat, options?: string[], ensureFile?: boolean): Promise<stencila.Node>;
/**
 * Unparse a `stencila.Node` to a `VFile`.
 *
 * @param node The `stencila.Node` to unparse
 * @param options Additional arguments to pass to Pandoc
 * @param ensureFile Ensure that the output is a real file (ie. not stdout?)
 * @returns A promise that resolves to a `VFile`
 */
export declare function unparse(node: stencila.Node, filePath?: string, to?: Pandoc.OutputFormat, options?: string[], ensureFile?: boolean): Promise<VFile>;
/**
 * Parse a Pandoc `Meta` node to an `object`
 */
export declare function parseMeta(meta: Pandoc.Meta): {
    [key: string]: stencila.Node;
};
/**
 * Unparse an `object` of metadata into a Pandoc `Meta` node
 */
export declare function unparseMeta(obj: {
    [key: string]: any;
}): Pandoc.Meta;
/**
 * Empty Pandoc element attributes
 */
export declare const emptyAttrs: Pandoc.Attr;
