"use strict";
/**
 * # PDF unparser
 *
 * @module pdf
 */
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./index");
const puppeteer = __importStar(require("./puppeteer"));
const vfile_1 = require("./vfile");
/**
 * The media types that this compiler can parse/unparse.
 */
exports.mediaTypes = ['application/pdf'];
// The above media type is registered in the `mime` module
// so there is no need to specify `extNames`
/**
 * This function is required (currently) but is (and probably never will be)
 * implemented.
 */
async function parse(file) {
    throw new Error(`Parsing of PDF files is not supported.`);
}
exports.parse = parse;
// The Puppeteer page that will be used to generate PDFs
exports.browser = puppeteer.page();
/**
 * Unparse a Stencila `Node` to a `VFile` with PDF content.
 *
 * @param node The Stencila `Node` to unparse
 * @param filePath The file system path to write the PDF to
 * @returns A promise that resolves to a `VFile`
 */
async function unparse(node, filePath) {
    const html = await index_1.dump(node, 'html');
    const page = await exports.browser();
    await page.setContent(html, { waitUntil: 'networkidle0' });
    const buffer = await page.pdf({
        path: filePath,
        format: 'A4',
        printBackground: true,
        margin: {
            top: '2.54cm',
            bottom: '2.54cm',
            left: '2.54cm',
            right: '2.54cm'
        }
    });
    return vfile_1.load(buffer);
}
exports.unparse = unparse;
