"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const puppeteer_1 = __importDefault(require("puppeteer"));
const boot_1 = require("./boot");
/**
 * Get an instance of a Puppeteer web browser `Page`.
 *
 * @returns A thunk that returns the same `puppeteer.Page`
 *          each time that it is called
 */
function page() {
    let browser;
    let page;
    /**
     * Startup the browser and create the
     * page if it isn't already.
     */
    async function startup() {
        if (!browser) {
            browser = await puppeteer_1.default.launch({
                executablePath: boot_1.chromiumPath,
                headless: true
            });
        }
        if (!page) {
            page = await browser.newPage();
        }
        return page;
    }
    /**
     * Close the browser.
     */
    async function shutdown() {
        if (browser) {
            await browser.close();
            browser = undefined;
        }
        page = undefined;
    }
    // Always shutdown before exiting the Node process
    // We use `beforeExit` because async operations are not supported
    // by `exit`.
    // See https://nodejs.org/api/process.html#process_event_beforeexit
    process.on('beforeExit', shutdown);
    function thunk(close) {
        return close ? shutdown() : startup();
    }
    return thunk;
}
exports.page = page;
