/**
 * Compiler for Tabular Data Package (TDP)
 *
 * The [TDP specification](https://specs.frictionlessdata.io/tabular-data-package/)
 * is a [Data Package](https://specs.frictionlessdata.io/data-package/) (represented by a
 * `datapackage.json` file) that has:
 *
 *  - at least one resource in the resources array
 *  - each resource must be a (Tabular Data Resource)[https://specs.frictionlessdata.io/tabular-data-resource/] (TDR)
 *
 * The TDR can be either:
 *
 * - inline "JSON tabular data" that is array of data rows where each row is an array or object"
 * - a CSV file
 */
import * as stencila from '@stencila/schema';
import { VFile } from './vfile';
export declare const mediaTypes: string[];
export declare const fileNames: string[];
export declare const extNames: string[];
export declare function parse(file: VFile): Promise<stencila.Node>;
export declare function unparse(node: stencila.Node, filePath?: string): Promise<VFile>;
/********************************************************************
 *  Field type, etc <-> DatatableColumnSchema
 ********************************************************************/
/**
 * Parse a Frictionless Data Table Schema [types and formats](https://frictionlessdata.io/specs/table-schema/#types-and-formats)
 * to JSON Schema [`type`](https://json-schema.org/understanding-json-schema/reference/type.html)
 * and [`format`](https://json-schema.org/understanding-json-schema/reference/string.html#format).
 */
export declare function parseFieldTypeFormat(type: null | string, format: null | string): {
    type: string | null;
    format: string | null;
    pattern: string | null;
};
/**
 * Parse a Frictionless Data Table Schema [constraints](https://frictionlessdata.io/specs/table-schema/#constraints) to
 * JSON Schema keywords such as `minimum`.
 *
 * Note that the the `unique` constraints are handled elsewhere. Only constraints that
 * apply to items should be returned here.
 */
export declare function parseFieldConstraints(constraints: {
    [key: string]: any;
}): {
    [key: string]: any;
};
