import * as stencila from '@stencila/schema';
/**
 * Create a node of a type
 * @param type The name of the type
 * @param initial Initial values for properties
 * @param validation What validation should done?
 */
export declare function create<Key extends keyof stencila.Types>(type: Key, initial?: {
    [key: string]: any;
}, validation?: 'none' | 'validate' | 'coerce'): stencila.Types[Key];
/**
 * Get the type of a node
 * @param node The node to get the type for
 */
export declare function type(node: any): string;
/**
 * Is a node of a particular type/s
 * @param node The node to check
 * @param types The type names to check against
 */
export declare function is(node: any, types: string | string[]): boolean;
/**
 * Assert that a node is of a particular type/s
 * @param node The node to check
 * @param types The type names to check against
 */
export declare function assert(node: any, types: string | string[]): boolean;
/**
 * Cast a node to a particular type
 *
 * The node is validated against the type.
 * This means that an error will be throw if during:
 *   - up-casting the node does not have properties
 *     that are required by the schema of the new type
 *   - down-casting the node has properties that
 *     are additional to those in the schema of the new type
 * Use `coerce` if you want to ignore such errors
 * and force mutating the node to the type.
 *
 * @param node The node to cast
 * @param type The type to cast to
 */
export declare function cast<Key extends keyof stencila.Types>(node: any, type: Key): stencila.Types[Key];
/**
 * Validate a node against a type's schema
 * @param node The node to validate
 * @param type The type to validate against
 */
export declare function validate<Key extends keyof stencila.Types>(node: any, type: Key): stencila.Types[Key];
/**
 * Is a node valid with respect to a particular type's schema
 * @param node The node to check
 * @param type The type to check against
 */
export declare function valid<Key extends keyof stencila.Types>(node: any, type: Key): boolean;
/**
 * Coerce a node so it conforms to a type's schema
 *
 * @param node The node to coerce
 * @param type The type to conform to
 */
export declare function coerce<Key extends keyof stencila.Types>(node: any, type: Key): stencila.Types[Key];
