/**
 * Compiler for Microsoft Excel.
 *
 * Also acts as base implementation for other spreadsheet-like formats
 * including `ods` and `csv`. Uses [`js-xlsx`]()`https://github.com/SheetJS/js-xlsx) to
 * parse and dump spreadsheets and transforms to/from the it's
 * (Common Spreadsheet Format)[https://github.com/SheetJS/js-xlsx#common-spreadsheet-format]
 * and Stencila schema instances.
 */
import * as stencila from '@stencila/schema';
import { VFile } from './vfile';
export declare const mediaTypes: string[];
export declare function parse(file: VFile): Promise<stencila.Node>;
export declare function unparse(node: stencila.Node, filePath?: string, format?: string): Promise<VFile>;
/**
 * Convert a column index (e.g. `27`) into a name (e.g. `AA`)
 *
 * Thanks to https://stackoverflow.com/a/182924.
 *
 * @param index The column index
 */
export declare function columnIndexToName(index: number): string;
/**
 * Convert a column name (e.g. `AA`) into an index (e.g. `27`)
 *
 * Thanks to https://stackoverflow.com/a/46173864.
 *
 * @param name The column name
 */
export declare function columnNameToIndex(name: string): number;
/**
 * Convert a cell name e.g. `A2` to a position e.g. `[0, 1]`
 *
 * @param name The name of the cell
 */
export declare function cellNameToPosition(name: string): [number, number];
/**
 * Convert a cell position e.g. `[0, 1]` to a name e.g. `A2`
 *
 * @param position The position of the cell
 */
export declare function cellPositionToName(position: [number, number]): string;
