/**
 * Compiler for Microsoft Word
 */

import stencila from '@stencila/schema'
import path from 'path'
import { home } from './boot'
import * as pandoc from './pandoc'
import { VFile } from './vfile'

export const mediaTypes = [
  'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
]

export async function parse(file: VFile): Promise<stencila.Node> {
  return pandoc.parse(
    file,
    pandoc.InputFormat.docx,
    [`--extract-media=${file.path}.media`],
    true
  )
}

/** Used to style conversion outputs targeting Microsoft Word */
const defaultDocxTemplatePath = path.join(
  home,
  'src',
  'templates',
  'stencila-template.docx'
)

export async function unparse(
  node: stencila.Node,
  filePath?: string,
  templatePath: string = defaultDocxTemplatePath
): Promise<VFile> {
  return pandoc.unparse(
    node,
    filePath,
    pandoc.OutputFormat.docx,
    [`--reference-doc=${templatePath}`],
    true
  )
}
